<?php
/**
 * Fileli functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Fileli
 */

if ( ! function_exists( 'fileli_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function fileli_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Fileli, use a find and replace
		 * to change 'fileli' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'fileli', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'primary' => esc_html__( 'Header', 'fileli' ),
			'footer' => esc_html__( 'Footer', 'fileli' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'fileli_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );
	/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, icons, and column width.
	 */
	  add_editor_style( array( 'fileli-editor-styles.css', fileli_fonts_url() ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );
	}
endif;
add_action( 'after_setup_theme', 'fileli_setup' );

/**
 * Register custom fonts.
 */
function fileli_fonts_url() {
	$fonts_url = '';

	/*
	 * Translators: If there are characters in your language that are not
	 * supported by Open sans, translate this to 'off'. Do not translate
	 * into your own language.
	 */
	$open_sans = _x( 'on', 'Open Sans font: on or off', 'fileli' );

	if ( 'off' !== $open_sans ) {
		$font_families = array();

		$font_families[] = 'Open Sans:400,400i,600,600i';

		$query_args = array(
			'family' => urlencode( implode( '|', $font_families ) ),
			'subset' => urlencode( 'latin-ext' ),
		);

		$fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
	}

	return esc_url_raw( $fonts_url );
}

/**
 * Add preconnect for Google Fonts.
 *
 * @since Twenty Seventeen 1.0
 *
 * @param array  $urls           URLs to print for resource hints.
 * @param string $relation_type  The relation type the URLs are printed.
 * @return array $urls           URLs to print for resource hints.
 */
function fileli_resource_hints( $urls, $relation_type ) {
	if ( wp_style_is( 'fileli-fonts', 'queue' ) && 'preconnect' === $relation_type ) {
		$urls[] = array(
			'href' => 'https://fonts.gstatic.com',
			'crossorigin',
		);
	}

	return $urls;
}
add_filter( 'wp_resource_hints', 'fileli_resource_hints', 10, 2 );

function ad_filter_menu($sorted_menu_objects, $args) {

    // https://wordpress.stackexchange.com/questions/87017/pulling-featured-images-in-to-a-wordpress-menu
    // check for the right menu to filter
    // here we check for the menu with name 'Posts Menu'
    // given that you call it in you theme with:
    //   wp_nav_menu( array( 'menu' => 'Posts Menu' ) );
    // if you call the menu using theme_location, eg:
    //   wp_nav_menu( array( 'theme_location' => 'top_manu' ) );
    // check for:
    //   if ($args->theme_location != 'top_menu')
    if ( ($args->theme_location != 'primary' && $args->theme_location != 'home') || !is_front_page())
        return $sorted_menu_objects;
    
    // edit the menu objects
    if ( $args->theme_location === 'primary') {
        foreach ($sorted_menu_objects as $menu_object) {
            // searching for menu items linking to posts or pages
            // can add as many post types to the array
            if ( in_array($menu_object->object, array('post', 'page', 'any_post_type')) ) {
                // Add the post_thumbnail if available
                // thumbnail size is the second parameter of get_the_post_thumbnail()
                $menu_object->title = has_post_thumbnail($menu_object->object_id) ? get_the_post_thumbnail($menu_object->object_id, 'thumbnail') . $menu_object->title : "<img src='/wp-content/themes/fileli/resources/fileli-symbol.svg' class='attachment-thumbnail size-thumbnail no-thumb' alt=''>" . $menu_object->title;
            }
        }
    }
    if ( $args->theme_location === 'home') {
        foreach ($sorted_menu_objects as $menu_object) {
            // searching for menu items linking to posts or pages
            // can add as many post types to the array
            if ( in_array($menu_object->object, array('post', 'page', 'any_post_type')) ) {
                // Add the post_thumbnail if available
                // thumbnail size is the second parameter of get_the_post_thumbnail()
//            echo "<pre>";print_r($menu_object);echo "</pre>";
                $menu_object->title = has_post_thumbnail($menu_object->object_id) ? get_the_post_thumbnail( $menu_object->object_id, 'medium_large') . '<h3>' . $menu_object->title . '</h3>' : '<h3>' . $menu_object->title . '</h3>';
            }
            $menu_object->title .= '<p>' . get_the_excerpt( $menu_object->object_id ) . '</p>';
        }
    }
    return $sorted_menu_objects;
}
add_filter('wp_nav_menu_objects', 'ad_filter_menu', 10, 2);


/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function fileli_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'fileli_content_width', 640 );
}
add_action( 'after_setup_theme', 'fileli_content_width', 0 );

/**
 * Give a personalized message for logged in users and a generic one for anonymous visitors
 */
function wpdocs_personal_message_when_logged_in() {
    if ( is_user_logged_in() ) {
        global $post;
        $status = (!empty($post)) ? $post->post_status: "" ;
        if ($status && $status!='publish') {
          echo '<div class="user_data status_closed"><p><span class="closed">status: ' . $status . '</span>';
        } else {
          echo '<div class="user_data"><p>';
        }
        $current_user = wp_get_current_user();
        printf( '<span><a href="'. get_edit_user_link( ) .'" title="Profile">%s</a> · %s</span><p></div>', esc_html( $current_user->user_login ), '<a href="' . wp_logout_url(get_permalink()) . '" title="Logout">logout</a>' );
    } else {
        printf( '<div class="user_data standby"><p><a href="%s" title="Login" class="aio-icon login-link">Login</a></p></div>', wp_login_url(get_permalink()));
    }
}
// add_action( 'get_user', 'wpdocs_personal_message_when_logged_in' );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function fileli_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'fileli' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'fileli' ),
		'before_widget' => '<li id="%1$s" class="widget %2$s">',
		'after_widget'  => '</li>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Header widgets', 'fileli' ),
		'id'            => 'header-widgets',
		'description'   => esc_html__( 'Add widgets here.', 'fileli' ),
		'before_widget' => '<li id="%1$s" class="widget %2$s">',
		'after_widget'  => '</li>',
		'before_title'  => '<span class="widget-title">',
		'after_title'   => '</span>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer widgets', 'fileli' ),
		'id'            => 'footer',
		'description'   => esc_html__( 'Add widgets here.', 'fileli' ),
		'before_widget' => '<li id="%1$s" class="widget %2$s">',
		'after_widget'  => '</li>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'fileli_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function fileli_scripts() {
// Inserire Google Font: Open sans 
  wp_enqueue_style('fileli-fonts', fileli_fonts_url() );
  wp_enqueue_style( 'fileli-style', get_stylesheet_uri() );

//   if (!is_admin()) wp_deregister_script('jquery');
  wp_enqueue_script( 'fileli-fonts', '//fast.fonts.net/jsapi/07d421c9-f323-4070-978d-57c9f7ede4c4.js', array(), false, false );
  wp_enqueue_script( 'fileli-main', get_template_directory_uri() . '/js/fileli-main-min.js', array(), false, true );
  wp_enqueue_script( 'fileli-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), false, true );

  if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
    wp_enqueue_script( 'comment-reply' );
  }
}
add_action( 'wp_enqueue_scripts', 'fileli_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

/**
 * Load recent entries.
 */
function aio_load_recent_entries($section) { 
    global $post;
    $parents = get_post_ancestors( $post->ID );
    $query = new WP_Query( array( 'post_parent' => $parents ) );
    $toplevel_parent = ($parents) ? $parents[count($parents)-1]: $post->ID;
    echo "<li>In preparazione</li>";
}
add_shortcode('aio_recententries', 'aio_load_recent_entries');

function wds_get_IDs_by_page_name($page_names) {
    global $wpdb;
    $theseNames = array_map('trim',explode(",", $page_names));
    $queryNames = "'" . implode("','", $theseNames) . "'";
    $page_name_ids = $wpdb->get_results("SELECT ID FROM $wpdb->posts WHERE post_name IN (" . $queryNames . ")", "ARRAY_N");
    $ids = array();
    foreach ($page_name_ids as $id) {
      array_push($ids, $id[0]);
    }
    return implode(',',$ids);
}

// add async/defer attributes

function add_async_attribute($tag, $handle) {
    if ( 'my-js-handle' !== $handle )
        return $tag;
    return str_replace( ' src', ' defer="defer" src', $tag );
}

/**
 * Set default category for new post.
 * https://wordpress.stackexchange.com/questions/77504/how-to-add-category-to-wp-admin-post-new-php
 
 * @wp-hook pre_option_default_category
 * @return  string Category slug
 */
function t5_get_default_cat_by_url()
{
    if ( ! isset( $_GET['post_cat'] ) )
        return FALSE;

    return array_map( 'sanitize_title', explode( ',', $_GET['post_cat'] ) );
}
add_action( 'wp_insert_post', 't5_draft_category', 10, 2 );

/**
 * Add category by URL parameter to auto-drafts.
 *
 * @wp-hook wp_insert_post
 * @param   int $post_ID
 * @param   object $post
 * @return  WP_Error|array An error object or term ID array.
 */
function t5_draft_category( $post_ID, $post )
{
    if ( ! $cat = t5_get_default_cat_by_url()
        or 'auto-draft' !== $post->post_status )
        return;

    // return value will be used in unit tests only.
    return wp_set_object_terms( $post_ID, $cat, 'category' );
}

/* custom category templates: 
// http://werdswords.com/force-sub-categories-use-the-parent-category-template/
// Theo

*/
function new_subcategory_hierarchy() {  
    $category = get_queried_object();
    $category_ancestors = get_ancestors($category->term_id, 'category');
    $templates = array();
     
    if ( empty($category_ancestors) ) {
        // Use default values from get_category_template()
        // exclude subs
        if ($category->slug != "subs") $templates[] = "category-{$category->slug}.php";
        $templates[] = "category-{$category->term_id}.php";
        $templates[] = 'category.php';      
    } else {
        // Create replacement $templates array
        $root = get_category(array_pop($category_ancestors));

        // Current first
        $templates[] = "category-{$category->slug}.php";
        $templates[] = "category-{$category->term_id}.php";
 
        // Parent second
        $templates[] = "category-{$root->slug}.php";
        $templates[] = "category-{$root->term_id}.php";
        $templates[] = 'category.php';  
    }
    return locate_template( $templates );
}
 
add_filter( 'category_template', 'new_subcategory_hierarchy' );

/*
* https://www.wpbeginner.com/wp-themes/create-custom-single-post-templates-for-specific-posts-or-sections-in-wordpress/
*/
 
function my_single_template($single) {
 
  $single_path = TEMPLATEPATH . '/single';
/**
* Checks for single template by category
* Check by category slug and ID
*/
  $subsCat = get_category_by_slug('subs');
  if (!empty($subsCat) && is_object($subsCat)) $subsCatId = $subsCat->cat_ID;
  
  if (!empty($subsCatId)) {
    foreach( (array)get_the_category() as $cat ) {
      if (file_exists($single_path  . '/single-cat-' . $subsCat->slug . '.php') && $cat->parent == $subsCatId ) {
        return $single_path  . '/single-cat-' . $subsCat->slug . '.php';
      } elseif(file_exists($single_path  . '/single-cat-' . $cat->term_id . '.php')) {
        return $single_path  . '/single-cat-' . $cat->term_id . '.php';
      }
    }
  }
  return TEMPLATEPATH . '/single.php';
}

add_filter('single_template', 'my_single_template');


/** get rid of the “Category:”, “Tag:”, “Author:”, “Archives:” and “Other taxonomy name:” in the archive title **/
/* function my_theme_archive_title( $title ) {
    if ( is_category() ) {
        $title = single_cat_title( '', false );
    } elseif ( is_tag() ) {
        $title = single_tag_title( '', false );
    } elseif ( is_author() ) {
        $title = '<span class="vcard">' . get_the_author() . '</span>';
    } elseif ( is_post_type_archive() ) {
        $title = post_type_archive_title( '', false );
    } elseif ( is_tax() ) {
        $title = single_term_title( '', false );
    }
  
    return $title;
}
 
add_filter( 'get_the_archive_title', 'my_theme_archive_title' ); */

function remove_h1_from_heading($args) {
// Just omit h1 from the list
$args['block_formats'] = 'Paragraph=p;Heading 1=h3;Heading 2=h4;Heading 3=h5;Heading 4=h6;Pre=pre';
return $args;
}
add_filter('tiny_mce_before_init', 'remove_h1_from_heading' );

function tinymce_config_59772( $init ) {
   // Don't remove line breaks
   $init['remove_linebreaks'] = false; 
   // Convert newline characters to BR tags
   $init['convert_newlines_to_brs'] = true; 
   // Do not remove redundant BR tags
   $init['remove_redundant_brs'] = false;

   // Pass $init back to WordPress
   return $init;
}
add_filter('tiny_mce_before_init', 'tinymce_config_59772');
